pub fn gamma(shape: f64, scale: f64) -> f64Expand description
A gamma distributed random number with density proportional to
x^(shape - 1) exp(-x / scale) (mean shape * scale)
(igraph_rng_get_gamma).
pub fn gamma(shape: f64, scale: f64) -> f64A gamma distributed random number with density proportional to
x^(shape - 1) exp(-x / scale) (mean shape * scale)
(igraph_rng_get_gamma).