pub fn normal(mean: f64, sd: f64) -> f64Expand description
A normally distributed random real with mean mean and standard
deviation sd, i.e. with density proportional to
exp(-(x - mean)² / (2 sd²))
(igraph_rng_get_normal).
pub fn normal(mean: f64, sd: f64) -> f64A normally distributed random real with mean mean and standard
deviation sd, i.e. with density proportional to
exp(-(x - mean)² / (2 sd²))
(igraph_rng_get_normal).